@@ -1,7 +1,3 @@
-context("naive Bayes - naivebayes")
-
-# ------------------------------------------------------------------------------
-
 library(mlbench)
 
 data(Glass)
@@ -15,8 +11,8 @@ in_samp <- sample.int(nrow(Glass), 5)
 # Add a random factor predictor to test dummy variables
 Glass$factor <- factor(sample(letters[1:3], nrow(Glass), replace = TRUE))
 
-glass_tr <- Glass[-in_samp,]
-glass_te <- Glass[ in_samp, -7]
+glass_tr <- Glass[-in_samp, ]
+glass_te <- Glass[in_samp, -7]
 glass_na <- glass_te
 glass_na$RI[1] <- NA
 glass_na$Na[2] <- NA
@@ -34,23 +30,30 @@ probs_to_tibble <- function(x) {
 
 # ------------------------------------------------------------------------------
 
-nb_spec   <- naive_Bayes(smoothness = 1.2) %>% set_engine("naivebayes")
-prior_spec <- naive_Bayes() %>% set_engine("naivebayes", prior = rep(1/6, 6))
+nb_spec <- naive_Bayes(smoothness = 1.2) %>% set_engine("naivebayes")
+prior_spec <- naive_Bayes() %>% set_engine("naivebayes", prior = rep(1 / 6, 6))
 
 
-exp_f_fit     <- naivebayes::naive_bayes(Type ~ ., data = glass_tr,
-                                         usekernel = TRUE, adjust = 1.2)
+exp_f_fit <- naivebayes::naive_bayes(
+  Type ~ .,
+  data = glass_tr,
+  usekernel = TRUE, adjust = 1.2
+)
 
-exp_xy_fit    <- naivebayes::naive_bayes(x = glass_tr[,-7], y = glass_tr$Type,
-                                         usekernel = TRUE, adjust = 1.2)
+exp_xy_fit <- naivebayes::naive_bayes(
+  x = glass_tr[, -7], y = glass_tr$Type,
+  usekernel = TRUE, adjust = 1.2
+)
 
-exp_prior_fit <- naivebayes::naive_bayes(x = glass_tr[,-7], y = glass_tr$Type,
-                                         prior = rep(1/6, 6), usekernel = TRUE)
+exp_prior_fit <- naivebayes::naive_bayes(
+  x = glass_tr[, -7], y = glass_tr$Type,
+  prior = rep(1 / 6, 6), usekernel = TRUE
+)
 
 
 # ------------------------------------------------------------------------------
 
-test_that('model object', {
+test_that("model object", {
 
   # formula method
   expect_error(f_fit <- fit(nb_spec, Type ~ ., data = glass_tr), NA)
@@ -67,7 +70,7 @@ test_that('model object', {
 
   # x/y method
   expect_error(
-    xy_fit <- fit_xy(nb_spec, x = glass_tr[,-7], y = glass_tr$Type),
+    xy_fit <- fit_xy(nb_spec, x = glass_tr[, -7], y = glass_tr$Type),
     NA
   )
   for (x in setdiff(names(xy_fit$fit$tables), "factor")) {
@@ -85,7 +88,7 @@ test_that('model object', {
   expect_equal(xy_fit$fit$tables[["factor"]], exp_xy_fit$tables[["factor"]])
 
   # pass an extra argument
-  expect_error(prior_fit <- fit_xy(prior_spec, x = glass_tr[,-7], y = glass_tr$Type), NA)
+  expect_error(prior_fit <- fit_xy(prior_spec, x = glass_tr[, -7], y = glass_tr$Type), NA)
   for (x in setdiff(names(prior_fit$fit$tables), "factor")) {
     x_dat <- prior_fit$fit$tables[[x]]
 
@@ -99,13 +102,12 @@ test_that('model object', {
     }
   }
   expect_equal(prior_fit$fit$tables[["factor"]], exp_prior_fit$tables[["factor"]])
-
 })
 
 # ------------------------------------------------------------------------------
 
 
-test_that('class predictions', {
+test_that("class predictions", {
   # formula method
   expect_error(f_fit <- fit(nb_spec, Type ~ ., data = glass_tr), NA)
   f_pred <- predict(f_fit, glass_te)
@@ -113,11 +115,11 @@ test_that('class predictions', {
 
   expect_s3_class(f_pred, "tbl_df")
   expect_true(all(names(f_pred) == ".pred_class"))
-  expect_equivalent(f_pred$.pred_class, exp_f_pred)
+  expect_equal(f_pred$.pred_class, exp_f_pred, ignore_attr = TRUE)
 
   # x/y method
   expect_error(
-    xy_fit <- fit_xy(nb_spec, x = glass_tr[,-7], y = glass_tr$Type),
+    xy_fit <- fit_xy(nb_spec, x = glass_tr[, -7], y = glass_tr$Type),
     NA
   )
   xy_pred <- predict(xy_fit, glass_te)
@@ -125,22 +127,22 @@ test_that('class predictions', {
 
   expect_s3_class(xy_pred, "tbl_df")
   expect_true(all(names(xy_pred) == ".pred_class"))
-  expect_equivalent(xy_pred$.pred_class, exp_xy_pred)
+  expect_equal(xy_pred$.pred_class, exp_xy_pred, ignore_attr = TRUE)
 
   # added argument
-  expect_error(prior_fit <- fit_xy(prior_spec, x = glass_tr[,-7], y = glass_tr$Type), NA)
+  expect_error(prior_fit <- fit_xy(prior_spec, x = glass_tr[, -7], y = glass_tr$Type), NA)
   prior_pred <- predict(prior_fit, glass_te)
   exp_prior_pred <- predict(exp_prior_fit, glass_te)
 
   expect_s3_class(f_pred, "tbl_df")
   expect_true(all(names(f_pred) == ".pred_class"))
-  expect_equivalent(prior_pred$.pred_class, exp_prior_pred)
+  expect_equal(prior_pred$.pred_class, exp_prior_pred, ignore_attr = TRUE)
 })
 
 # ------------------------------------------------------------------------------
 
 
-test_that('prob predictions', {
+test_that("prob predictions", {
   # formula method
   expect_error(f_fit <- fit(nb_spec, Type ~ ., data = glass_tr), NA)
   f_pred <- predict(f_fit, glass_te, type = "prob")
@@ -152,7 +154,7 @@ test_that('prob predictions', {
 
   # x/y method
   expect_error(
-    xy_fit <- fit_xy(nb_spec, x = glass_tr[,-7], y = glass_tr$Type),
+    xy_fit <- fit_xy(nb_spec, x = glass_tr[, -7], y = glass_tr$Type),
     NA
   )
   xy_pred <- predict(xy_fit, glass_te, type = "prob")
@@ -163,7 +165,7 @@ test_that('prob predictions', {
   expect_equal(xy_pred, exp_xy_pred)
 
   # added argument
-  expect_error(prior_fit <- fit_xy(prior_spec, x = glass_tr[,-7], y = glass_tr$Type), NA)
+  expect_error(prior_fit <- fit_xy(prior_spec, x = glass_tr[, -7], y = glass_tr$Type), NA)
   prior_pred <- predict(prior_fit, glass_te, type = "prob")
   exp_prior_pred <- probs_to_tibble(predict(exp_prior_fit, glass_te, type = "prob"))
 
@@ -175,7 +177,7 @@ test_that('prob predictions', {
 # ------------------------------------------------------------------------------
 
 
-test_that('missing data', {
+test_that("missing data", {
   expect_error(f_fit <- fit(nb_spec, Type ~ ., data = glass_tr), NA)
   f_pred <- predict(f_fit, glass_na, type = "prob")
   exp_f_pred <- probs_to_tibble(predict(exp_f_fit, glass_na, type = "prob"))
@@ -188,10 +190,6 @@ test_that('missing data', {
 
 # ------------------------------------------------------------------------------
 
-test_that('printing', {
-  expect_output(
-    print(nb_spec),
-    "Naive Bayes Model Specification"
-  )
+test_that("printing", {
+  expect_snapshot(print(nb_spec))
 })
-
